@@ -4,7 +4,7 @@ import string
 # Strings with embedded variables in Python
 # https://stackoverflow.com/a/16553401/598057
 class RubyTemplate(string.Template):
-    delimiter = '#'
+    delimiter = "#"
 
 
 REQUIREMENT_FIELDS = """
@@ -14,29 +14,46 @@ REQUIREMENT_FIELDS = """
 
   ('TAGS: ' (tags = TagRegex) tags *= TagXs '\n')?
 
-  ('REFS:' '\n' references *= Reference)?
+  ('SPECIAL_FIELDS:' '\n' special_fields += SpecialField)?
 
+  ('REFS:' '\n' references *= Reference)?
+  
   ('TITLE: ' title = /.*$/ '\n')?
 
   ('STATEMENT: ' (statement = SingleLineString | statement_multiline = MultiLineString) '\n')?
 
   ('BODY: ' body = MultiLineString '\n' )?
 
+  ('RATIONALE: ' (rationale = SingleLineString | rationale_multiline = MultiLineString) '\n')?
+
   comments *= RequirementComment
 """
 
-STRICTDOC_GRAMMAR = RubyTemplate("""
+STRICTDOC_GRAMMAR = RubyTemplate(
+    """
 Document[noskipws]:
   '[DOCUMENT]' '\n'
-  'NAME: ' name = /.*$/ '\n'
+  // NAME: is deprecated. Both documents and sections now have TITLE:.
+  (('NAME: ' name = /.*$/ '\n') | ('TITLE: ' title = /.*$/ '\n')?)
+  (config = DocumentConfig)? 
   free_texts *= SpaceThenFreeText
   section_contents *= SectionOrRequirement
 ;
 
+DocumentConfig[noskipws]:
+('SPECIAL_FIELDS:' '\n' special_fields += ConfigSpecialField)?
+;
+
+ConfigSpecialField[noskipws]:
+'- NAME: ' field_name = /.*$/ '\n'
+'  TYPE: ' field_type = 'String' '\n'
+('  REQUIRED: ' field_required = 'Yes' '\n')?
+;
+
 Section[noskipws]:
   '[SECTION]' 
   '\n'
-  'LEVEL: ' level = /[1-6]/ '\n'
+  ('LEVEL: ' level = /[1-6]/ '\n')?
   'TITLE: ' title = /.*$/ '\n'
   free_texts *= SpaceThenFreeText
   section_contents *= SectionOrRequirement
@@ -64,14 +81,18 @@ Requirement[noskipws]:
 ;
 
 CompositeRequirement[noskipws]:
-  '[COMPOSITE-REQUIREMENT]' '\n'
+  '[COMPOSITE_REQUIREMENT]' '\n'
 
   #{REQUIREMENT_FIELDS}
   
   requirements *= SpaceThenRequirement
 
   '\n'
-  '[/COMPOSITE-REQUIREMENT]' '\n'
+  '[/COMPOSITE_REQUIREMENT]' '\n'
+;
+
+SpecialField[noskipws]:
+  '  ' field_name = /[A-Z][A-Z0-9_]+/ ': ' field_value = /.*$/ '\n'
 ;
 
 TagRegex[noskipws]:
@@ -109,4 +130,5 @@ ReferenceType[noskipws]:
 FreeText[noskipws]:
   text = /(?ms)\[FREETEXT\]\n(.*?)\n\[\/FREETEXT\]/ '\n'
 ;
-""").substitute(REQUIREMENT_FIELDS=REQUIREMENT_FIELDS)
+"""
+).substitute(REQUIREMENT_FIELDS=REQUIREMENT_FIELDS)
