@@ -1,6 +1,9 @@
 from enum import Enum
 
-from strictdoc.backend.dsl.models.requirement import Requirement, CompositeRequirement
+from strictdoc.backend.dsl.models.requirement import (
+    Requirement,
+    CompositeRequirement,
+)
 from strictdoc.backend.dsl.models.section import Section, FreeText
 from strictdoc.core.document_iterator import DocumentCachingIterator
 
@@ -22,17 +25,38 @@ class SDWriter:
         output += "[DOCUMENT]"
         output += "\n"
 
-        output += "NAME: "
+        output += "TITLE: "
         output += document.name
         output += "\n"
 
+        document_config = document.config
+        if document_config:
+            config_special_fields = document_config.special_fields
+            if config_special_fields:
+                output += "SPECIAL_FIELDS:"
+                output += "\n"
+
+                for config_special_field in config_special_fields:
+                    output += "- NAME: "
+                    output += config_special_field.field_name
+                    output += "\n"
+                    output += "  TYPE: "
+                    output += config_special_field.field_type
+                    output += "\n"
+                    if config_special_field.field_required:
+                        output += "  REQUIRED: Yes"
+                        output += "\n"
+
         for free_text in document.free_texts:
             output += "\n"
             output += self._print_free_text(free_text)
 
         closing_tags = []
         for content_node in document_iterator.all_content():
-            while len(closing_tags) > 0 and content_node.ng_level <= closing_tags[-1][1]:
+            while (
+                len(closing_tags) > 0
+                and content_node.ng_level <= closing_tags[-1][1]
+            ):
                 closing_tag, level = closing_tags.pop()
                 output += self._print_closing_tag(closing_tag)
 
@@ -43,8 +67,10 @@ class SDWriter:
                 closing_tags.append((TAG.SECTION, content_node.ng_level))
             elif isinstance(content_node, Requirement):
                 if isinstance(content_node, CompositeRequirement):
-                    output += "[COMPOSITE-REQUIREMENT]\n"
-                    closing_tags.append((TAG.COMPOSITE_REQUIREMENT, content_node.ng_level))
+                    output += "[COMPOSITE_REQUIREMENT]\n"
+                    closing_tags.append(
+                        (TAG.COMPOSITE_REQUIREMENT, content_node.ng_level)
+                    )
                 else:
                     output += "[REQUIREMENT]\n"
 
@@ -57,12 +83,9 @@ class SDWriter:
 
     def _print_section(self, section):
         assert isinstance(section, Section)
-        output = ''
+        output = ""
         output += "[SECTION]"
         output += "\n"
-        output += "LEVEL: "
-        output += str(section.level)
-        output += "\n"
         output += "TITLE: "
         output += str(section.title)
         output += "\n"
@@ -72,7 +95,7 @@ class SDWriter:
         return output
 
     def _print_requirement_fields(self, section_content):
-        output = ''
+        output = ""
 
         if section_content.uid:
             output += "UID: "
@@ -86,8 +109,18 @@ class SDWriter:
 
         if section_content.tags:
             output += "TAGS: "
-            output += ', '.join(section_content.tags)
-            output += '\n'
+            output += ", ".join(section_content.tags)
+            output += "\n"
+
+        if section_content.special_fields:
+            output += "SPECIAL_FIELDS:"
+            output += "\n"
+
+            for special_field in section_content.special_fields:
+                output += (
+                    f"  {special_field.field_name}: {special_field.field_value}"
+                )
+                output += "\n"
 
         if section_content.references:
             output += "REFS:"
@@ -117,8 +150,6 @@ class SDWriter:
             output += "\n"
             output += "<<<"
             output += "\n"
-        else:
-            raise RuntimeError('Statement is missing: {}'.format(section_content))
 
         if section_content.body:
             output += "BODY: >>>"
@@ -128,6 +159,15 @@ class SDWriter:
             output += "<<<"
             output += "\n"
 
+        if section_content.rationale_multiline:
+            output += "RATIONALE: >>>\n"
+            output += section_content.rationale_multiline
+            output += "\n<<<\n"
+        elif section_content.rationale:
+            output += "RATIONALE: "
+            output += section_content.rationale
+            output += "\n"
+
         for comment in section_content.comments:
             if comment.comment_multiline:
                 output += "COMMENT: >>>\n"
@@ -141,24 +181,24 @@ class SDWriter:
         return output
 
     def _print_closing_tag(self, closing_tag):
-        output = ''
+        output = ""
         if closing_tag == TAG.SECTION:
-            output += '\n'
-            output += '[/SECTION]'
-            output += '\n'
+            output += "\n"
+            output += "[/SECTION]"
+            output += "\n"
         if closing_tag == TAG.COMPOSITE_REQUIREMENT:
-            output += '\n'
-            output += '[/COMPOSITE-REQUIREMENT]'
-            output += '\n'
+            output += "\n"
+            output += "[/COMPOSITE_REQUIREMENT]"
+            output += "\n"
         return output
 
     def _print_free_text(self, free_text):
         assert isinstance(free_text, FreeText)
-        output = ''
-        output += '[FREETEXT]'
-        output += '\n'
+        output = ""
+        output += "[FREETEXT]"
+        output += "\n"
         output += free_text.text.rstrip()
-        output += '\n'
-        output += '[/FREETEXT]'
-        output += '\n'
+        output += "\n"
+        output += "[/FREETEXT]"
+        output += "\n"
         return output
