@@ -1,5 +1,7 @@
 from jinja2 import Environment, PackageLoader
 
+from strictdoc.export.html.document_type import DocumentType
+
 
 class DocumentTableHTMLGenerator:
     env = Environment(
@@ -18,6 +20,7 @@ class DocumentTableHTMLGenerator:
         output += template.render(document=document,
                                   traceability_index=traceability_index,
                                   renderer=markup_renderer,
-                                  link_renderer=link_renderer)
+                                  link_renderer=link_renderer,
+                                  document_type=DocumentType.table())
 
         return output
